@@ -1,4 +1,3 @@
-from typing import Union
 import os
 
 import dask.array as da
@@ -6,25 +5,17 @@ import h5py
 import numpy as np
 from skimage import measure
 
-from ...contour_manager import ContourManager
 from ...images.masks import make_scalar_mask
 from ..utils.data_range import calc_data_range
 from ._vendored import load_dict_from_hdf5, load_memmap
 
 
-def make_caiman_contour_manager(
-    img_components: np.ndarray, good_indices: Union[list, np.ndarray]
-) -> ContourManager:
-    contours = [measure.find_contours(comp, 40)[0] for comp in img_components]
-    initial_state = np.zeros((len(contours),), dtype=np.bool)
-    initial_state[good_indices] = True
-    contour_manager = ContourManager(
-        contours,
-        initial_state=initial_state,
-        im_shape=img_components[0, ...].shape,
-    )
+def make_caiman_cell_masks(img_components: np.ndarray) -> list:
+    cell_masks = [
+        measure.find_contours(comp, 40)[0] for comp in img_components
+    ]
 
-    return contour_manager
+    return cell_masks
 
 
 def load_movie(filename: str, dataset_name: str = 'mov'):
@@ -80,19 +71,17 @@ def caiman_reader(
     )
     img_components = img_components * 255
     estimates["img_components"] = img_components.astype(np.uint8)
-    contour_manager = make_caiman_contour_manager(
-        estimates["img_components"], good_indices=estimates["idx_components"]
-    )
+    cell_masks = make_caiman_cell_masks(estimates["img_components"])
+
+    good_indices = estimates["idx_components"]
+    initial_cell_masks_state = np.zeros((len(cell_masks),), dtype=np.bool)
+    initial_cell_masks_state[good_indices] = True
 
     # calculate the SNR and make the mask
     snr = estimates["SNR_comp"]
     im_shape = im_registered.shape
-    contours = [
-        measure.find_contours(comp, 40)[0]
-        for comp in estimates["img_components"]
-    ]
     snr_mask = make_scalar_mask(
-        contours, im_shape=(im_shape[-2], im_shape[-1]), values=snr
+        cell_masks, im_shape=(im_shape[-2], im_shape[-1]), values=snr
     )
 
     # get the fluorescence data
@@ -105,7 +94,8 @@ def caiman_reader(
     return (
         im_registered,
         data_range,
-        contour_manager,
+        cell_masks,
+        initial_cell_masks_state,
         f_traces,
         snr,
         snr_mask,
