@@ -1,7 +1,9 @@
 import argparse
 import os
 
-from .calcium_curator import calcium_curator
+import napari
+
+from .calcium_curator import CalciumCurator
 from .io.caiman.caiman_reader import caiman_reader
 from .io.caiman._vendored import load_dict_from_hdf5
 
@@ -26,27 +28,29 @@ def view_caiman():
     cnm_obj = load_dict_from_hdf5(results_file)
 
     if image_path == "":
-        im_name_base = os.path.basename(
-            os.path.splitext(cnm_obj['mmap_file'])[0]
-        )
-        results_dir = os.path.dirname(results_file)
-        image_path_base = os.path.join(results_dir, im_name_base)
         # first check if there's a motion corrected hdf5 file
         # if not, try the caiman mmap file
-        if os.path.isfile(image_path_base + '_mcorr.hdf5'):
-            image_path = image_path_base + '_mcorr.hdf5'
-        else:
-            image_path = image_path_base + '.mmap'
+        results_base = os.path.splitext(results_file)[0]
+        image_path = results_base + '_mcorr.hdf5'
         if not os.path.isfile(image_path):
-            raise FileNotFoundError(
-                "Image file not found in results directory.\n"
-                "Try passing the image file path with the --image argument"
+            results_dir = os.path.dirname(results_file)
+            im_name_base = os.path.basename(
+                os.path.splitext(cnm_obj['mmap_file'])[0]
             )
+            image_path_base = os.path.join(results_dir, im_name_base)
+            image_path = image_path_base + '.mmap'
+
+            if not os.path.isfile(image_path):
+                raise FileNotFoundError(
+                    "Image file not found in results directory.\n"
+                    "Try passing the image file path with the --image argument"
+                )
 
     (
         im_registered,
         data_range,
-        contour_manager,
+        cell_masks,
+        initial_cell_masks_state,
         f_traces,
         snr,
         snr_mask,
@@ -54,14 +58,16 @@ def view_caiman():
         is_cell,
     ) = caiman_reader(results_file, image_path)
 
-    calcium_curator(
-        img=im_registered,
-        data_range=data_range,
-        contour_manager=contour_manager,
-        f=f_traces,
-        snr=snr,
-        snr_mask=snr_mask,
-        spikes=spikes,
-        output=output_dir,
-        cells=is_cell,
-    )
+    with napari.gui_qt():
+        CalciumCurator(
+            img=im_registered,
+            data_range=data_range,
+            cell_masks=cell_masks,
+            initial_cell_masks_state=initial_cell_masks_state,
+            f=f_traces,
+            snr=snr,
+            snr_mask=snr_mask,
+            spikes=spikes,
+            output=output_dir,
+            cells=is_cell,
+        )
